import io
import magic
import oss2
import requests
from PIL import Image
def img_cut(content,exceed_size,down_height=None,height=None):
    """
    content:需要处理的img的二进制
    exceed_size:当图片尺寸大于该尺寸进行裁剪
    down_height:从底部开始裁剪
    height:从上边开始裁剪
    """
    kind = magic.from_buffer(content, mime=True).split('/')[-1]
    img = Image.open(io.BytesIO(content))
    x_max = img.size[0]
    y_max = img.size[1]
    img_bytes = io.BytesIO()
    if int(y_max) > exceed_size:
        if down_height:
            img_bytes = io.BytesIO()
            cropped = img.crop((0, 0, x_max, y_max-down_height))  # (left, upper, right, lower)
            cropped.save(img_bytes, format=kind)
            # 从字节流管道中获取二进制
            image_bytes = img_bytes.getvalue()
            return image_bytes
        if height:
            cropped = img.crop((0, 0, x_max,height))  # (left, upper, right, lower)
            cropped.save(img_bytes, format=kind)
            # 从字节流管道中获取二进制
            image_bytes = img_bytes.getvalue()
            return image_bytes

def img_to_pdf(content_s):
    """
    content_s:需要处理的img图片的二进制,list类型
    """
    imgs = []
    for content in content_s:
        img = Image.open(io.BytesIO(content))
        # PNG格式转换成的四通道转成RGB的三通道
        img = img.convert("RGB")
        imgs.append(img)
    pdf_bytes = io.BytesIO()
    img0 = imgs[0]
    imgs = imgs[1:]
    img0.save(pdf_bytes,"PDF", resolution=100.0, save_all=True, append_images=imgs)
    return pdf_bytes.getvalue()







from __future__ import print_function
from setuptools import setup, find_packages
import sys
magic_package_choice = 'python-magic-bin==0.4.14' if sys.platform.startswith("win") else 'python-magic==0.4.24'

# def read_file(filename):
#     with open(filename) as fp:
#         return fp.read().strip()
#
# def read_requirements(filename):
#     return [line.strip() for line in read_file(filename).splitlines()
#             if not line.startswith('#')]

# REQUIRED = read_requirements('requirements.txt')
setup(
    name='ImgAlter',
    version='0.1.8',
    author='White.tie',
    author_email='1042798703@qq.com',
    url='https://github.com/tyj-1995',
    description='1.Resize the image, 2.image transfer pdf',
    long_description='1.修改图片大小, 2.图片转成pdf',
    packages=['ImgAlter'],
    install_requires=["pillow>=8.0.1",
                      magic_package_choice],
    classifiers=[
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Topic :: Text Processing :: Indexing",
        "Topic :: Utilities",
        "Topic :: Internet",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.6",
        "Programming Language :: Python :: 3.6",
        ],
)
